@@ -7,8 +7,8 @@
 
 ;; URL: https://codeberg.org/ideasman42/emacs-hl-prog-extra
 ;; Keywords: convenience
-;; Package-Version: 20250923.2251
-;; Package-Revision: 51a78d2e1989
+;; Package-Version: 20251106.1059
+;; Package-Revision: 40b4e757cb7c
 ;; Package-Requires: ((emacs "26.2"))
 
 ;;; Commentary:
@@ -224,7 +224,7 @@ check this buffer.")
          (validate-re-fn
           (lambda (re)
             (catch 'error
-              (when (not (stringp re))
+              (unless (stringp re)
                 (throw 'error (format "expected a string, not a %S!" (type-of re))))
 
               (let ((item-error (hl-prog-extra--regexp-valid-or-error re)))
@@ -306,7 +306,7 @@ check this buffer.")
          (validate-face-single-fn
           (lambda (face)
             (catch 'error
-              (when (not (or (facep face) (listp face)))
+              (unless (or (facep face) (listp face))
                 (throw
                  'error
                  (format
@@ -324,7 +324,7 @@ check this buffer.")
                     (throw 'error error-msg))))
 
               ;; Now check the face list is compatible with `re-subexpr'.
-              (when (not (eq (length re-subexpr) (length face)))
+              (unless (eq (length re-subexpr) (length face))
                 (throw 'error "list lengths do not match!")))))
 
          (validate-face-fn
